@@ -147,11 +147,29 @@ sub unpack {
 	$this->SUPER::unpack(@_);
 	my $workdir=$this->unpacked_tree;
 	
-	
-	
 	$this->do("rpm2cpio ".$this->filename." | (cd $workdir; cpio --extract --make-directories --no-absolute-filenames --preserve-modification-time) 2>&1")
 		or die "Unpacking of '".$this->filename."' failed";
 	
+	# cpio does not necessarily store all parent directories in an
+	# archive, and so some directories, if it has to make them and has
+	# no permission info, will come out with some random permissions.
+	# Find those directories and make them mode 755, which is more
+	# reasonable.
+	my %seenfiles;
+	open (RPMLIST, "rpm2cpio ".$this->filename." | cpio -it --quiet |")
+		or die "File list of '".$this->filename."' failed";
+	while (<RPMLIST>) {
+		chomp;
+		$seenfiles{$_}=1;
+	}
+	close RPMLIST;
+	foreach my $file (`cd $workdir; find ./`) {
+		chomp $file;
+		if (! $seenfiles{$file} && -d "$workdir/$file" && ! -l "$workdir/$file") {
+			$this->do("chmod 755 $workdir/$file");
+		}
+	}
+
 	# If the package is relocatable. We'd like to move it to be under
 	# the $this->prefixes directory. However, it's possible that that
 	# directory is in the package - it seems some rpm's are marked as
@@ -189,18 +207,6 @@ sub unpack {
 		}
 		$this->conffiles([@cf]);
 	}
-
-	# cpio does not necessarily store all parent directories in an
-	# archive, and so some directories, if it has to make them and has
-	# no permission info, will come out with whatever the default mode
-	# is for the current umask. Here I just chown all such directories
-	# to mode 755, which is more reasonable. Note that the next section
-	# overrides these default permissions, if override data exists in
-	# the rpm permissions info, but it won't always exist for parent
-	# directories.
-	$this->do("find $workdir -type d -perm ".
-		(sprintf "%lo", 0777 &~ umask).
-		" -print0 | xargs --no-run-if-empty -0 chmod 755");
 	
 	# rpm files have two sets of permissions; the set in the cpio
 	# archive, and the set in the control data; which override them.
@@ -292,7 +298,7 @@ sub prep {
 	print OUT "Requires: ".$this->depends."\n"
 		if defined $this->depends && length $this->depends;
 	print OUT "Summary: ".$this->summary."\n";
-	print OUT "Copyright: ".$this->copyright."\n";
+	print OUT "License: ".$this->copyright."\n";
 	print OUT "Distribution: ".$this->distribution."\n";
 	print OUT "Group: Converted/".$this->group."\n";
 	print OUT "\n";
@@ -316,7 +322,7 @@ sub prep {
 			print OUT $this->prerm."\n";
 			print OUT "\n";
 		}
-		if ($this->postun) {
+		if ($this->postrm) {
 			print OUT "\%postun\n";
 			print OUT $this->postrm."\n";
 			print OUT "\n";
@@ -391,7 +397,7 @@ sub build {
 		$opts="--target ".$this->arch;
 	}
 
-	$opts.=" $ENV{RPMBUILDOPTS}" if exists $ENV{RPMBUILDOPTS};
+	$opts.=" $ENV{RPMBUILDOPT}" if exists $ENV{RPMBUILDOPT};
 	my $command="cd $dir; $buildcmd -bb $opts ".$this->name."-".$this->version."-".$this->release.".spec";
 	my $log=$this->runpipe(1, "$command 2>&1");
 	if ($?) {
@@ -530,17 +536,21 @@ sub arch {
 		elsif ($arch eq 'x86_64') {
 			$arch='amd64';
 		}
-	
-		# Treat 486, 586, etc, as 386.
-		if ($arch =~ m/i\d86/i || $arch =~ m/pentium/i) {
+		elsif ($arch eq 'em64t') {
+			$arch='amd64';
+		}
+		elsif ($arch =~ m/i\d86/i || $arch =~ m/pentium/i) {
+			# Treat 486, 586, etc, as 386.
 			$arch='i386';
 		}
-	
-		# Treat armv4l as arm.
-		if ($arch eq 'armv4l') {
+		elsif ($arch eq 'armv4l') {
+			# Treat armv4l as arm.
 			$arch='arm';
 		}
-	
+		elsif ($arch eq 'parisc') {
+			$arch='hppa';
+		}
+		
 		$this->{arch}=$arch;
 	}
 
@@ -553,6 +563,9 @@ sub arch {
 		# systems?
 		$arch='ppc';
 	}
+	elsif ($arch eq 'hppa') {
+		$arch='parisc';
+	}
 	elsif ($arch eq 'all') {
 		$arch='noarch';
 	}
